@@ -40,6 +40,7 @@ import editorstate
 from editorstate import PROJECT
 from editorstate import PLAYER
 from editorstate import current_sequence
+import extraeditors
 import gui
 import guicomponents
 import guipopover
@@ -386,6 +387,10 @@ class ClipFilterStack:
         filter_stack_item = self.filter_stack[filter_index]
         filter_stack_item.expander.set_expanded(True)
 
+    def set_filter_item_minified(self, filter_index):
+        filter_stack_item = self.filter_stack[filter_index]
+        filter_stack_item.expander.set_expanded(False)
+        
     def set_all_filters_expanded_state(self, expanded):
         for i in range(0, len(self.filter_stack)):
             stack_item = self.filter_stack[i]
@@ -468,14 +473,6 @@ def set_clip(clip, track, clip_index, show_tab=True):
 
     gui.editor_window.edit_multi.set_visible_child_name(appconsts.EDIT_MULTI_FILTERS)
 
-    #global _edit_polling_thread
-    # Close old polling
-    #if _edit_polling_thread != None:
-    #    _edit_polling_thread.shutdown()
-    # Start new polling
-    #_edit_polling_thread = PropertyChangePollingThread()
-    #_edit_polling_thread.start()
-
 def refresh_clip():
     if _filter_stack == None:
         return 
@@ -573,7 +570,6 @@ def clear_clip():
     show_text_in_edit_area(_("No Clip"))
 
     set_enabled(False)
-    # shutdown_polling()
 
     global keyframe_editor_widgets
     keyframe_editor_widgets = []
@@ -612,14 +608,6 @@ def update_stack(clip, track, clip_index):
 
     widgets.value_edit_box = scroll_window
 
-"""
-def update_stack_changed_blocked():
-    global _block_changed_update
-    _block_changed_update = True
-    update_stack()
-    _block_changed_update = False
-"""
-
 def _alpha_filter_add_maybe_info(filter_info):
     if editorpersistance.prefs.show_alpha_info_message == True and \
        editorstate. current_sequence().compositing_mode != appconsts.COMPOSITING_MODE_STANDARD_FULL_TRACK:
@@ -761,6 +749,7 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
                 or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_RELEASE)
                 or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_CLIP)
                 or (editor_type == propertyeditorbuilder.FILTER_RECT_GEOM_EDITOR)
+                or (editor_type == propertyeditorbuilder.NO_KF_RECT)
                 or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_CLIP_FADE_FILTER)):
                     keyframe_editor_widgets.append(editor_row)
                     filter_keyframe_editor_widgets.append(editor_row)
@@ -774,10 +763,20 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
             if not hasattr(editor_row, "no_separator"):
                 vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
             
+            # Some editors need to be accessed by extraeditors for controlling their state.
+            try:
+                name = ep.args[propertyedit.ACCESSABLE_EDITOR]
+                filter_index = ep.filter_index
+                extraeditors.accessable_editors[name + ":" + str(filter_index)] = editor_row
+            except Exception as e:
+                pass
+
         # Create NonMltEditableProperty wrappers for properties
         non_mlteditable_properties = propertyedit.get_non_mlt_editable_properties( clip, 
                                                                                    filter_object,
-                                                                                   filter_index)
+                                                                                   filter_index,
+                                                                                   track,
+                                                                                   clip_index)
 
         # Extra editors. Editable properties may have already been created 
         # with "editor=no_editor" and now extra editors may be created to edit those
@@ -788,6 +787,12 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
             vbox.pack_start(editor_row, False, False, 0)
             if not hasattr(editor_row, "no_separator"):
                 vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
+            if hasattr(editor_row, "kf_edit_geom_editor"):
+                # kf_edit_geom_editor is keyframeeditor.FilterRotatingGeometryEditor,
+                # the widget that actually needs to be updated.
+                # editor_row is just Gtk.VBox.
+                keyframe_editor_widgets.append(editor_row.kf_edit_geom_editor)
+                filter_keyframe_editor_widgets.append(editor_row.kf_edit_geom_editor)
     else:
         vbox.pack_start(Gtk.Label(label=_("No editable parameters")), True, True, 0)
     vbox.show_all()
@@ -909,7 +914,7 @@ def _filter_mask_item_activated(action, variant, data):
 
     set_clip(clip, track, clip_index)
     _filter_stack.set_filter_item_expanded(current_filter_index + 1)
-
+    _filter_stack.set_filter_item_minified(current_filter_index + 2)
 
 # ------------------------------------------------ SAVE, LOAD etc. from hamburger menu
 def _hamburger_launch_pressed(launcher, widget, event, data):
