@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@ RENDER_TICKER_DELAY = 0.05
 
 _current_profile = None
 
+
 def set_current_profile(clip_path):
     profile = mltprofiles.get_default_profile()
     producer = mlt.Producer(profile, str(clip_path))
@@ -53,6 +54,10 @@ def set_current_profile(clip_path):
     _current_profile = mltprofiles.get_profile_for_index(profile_index)
     return profile_index
 
+def set_current_profile_as_default_profile():
+    global _current_profile
+    _current_profile = mltprofiles.get_default_profile()
+
 def set_current_profile_for_profile_name(profile_name):
     global _current_profile
     _current_profile = mltprofiles.get_profile(profile_name)
